@@ -22,8 +22,7 @@ test_that('manip_bin_numerics'
 
   categoricals = c('cyl', 'vs', 'am', 'gear', 'carb')
 
-  data = mtcars %>%
-    mutate_at( vars(categoricals), as.factor )
+  data = mtcars2
 
   data_new = manip_bin_numerics(data)
 
@@ -47,12 +46,6 @@ test_that('manip_bin_numerics'
   
   data_new_min_max = manip_bin_numerics(data, bin_labels = 'min_max')
   
-  # p1 = alluvial_wide(data)
-  # 
-  # p2 = alluvial_wide(data, bin_labels = 'min_max')
-  # 
-  # gridExtra::grid.arrange(p1,p2)
-  
   expect_false( identical(data_new_cuts, data_new_median) )
   
   expect_false( identical(data_new_mean, data_new_median) )
@@ -98,5 +91,67 @@ test_that('manip_bin_numerics with vector'
 
   vec = manip_bin_numerics( as.factor(mtcars$cyl) )
   expect_identical( vec, as.factor(mtcars$cyl) )
-
+  
+  df = tibble( a = rnorm(50), b = rnorm(50), c = seq(1:50) ) %>%
+    mutate( c = as.character(c) )
+  
+  df_v1 = manip_bin_numerics(df)
+  
+  df_v2 = df %>%
+    mutate( a = manip_bin_numerics(a)
+            , b = manip_bin_numerics(b)
+            , c = as.character( seq(1:50) ) )
+  
+  expect_identical( df_v1, df_v2)
+  
+  df_v1 = manip_bin_numerics(df, bin_labels = 'median')
+  
+  df_v2 = df %>%
+    mutate( a = manip_bin_numerics(a, bin_labels = 'median')
+            , b = manip_bin_numerics(b, bin_labels = 'median')
+            , c = as.character( seq(1:50) ) )
+  
+  expect_identical( df_v1, df_v2)
+  
+  df_v1 = manip_bin_numerics(df, bin_labels = 'min_max')
+  
+  df_v2 = df %>%
+    mutate( a = manip_bin_numerics(a, bin_labels = 'min_max')
+            , b = manip_bin_numerics(b, bin_labels = 'min_max')
+            , c = as.character( seq(1:50) ) )
+  
+  expect_identical( df_v1, df_v2 )
+  
 })
+ 
+test_that('manip_bin_numerics_NA',{
+  
+  v =  rnorm(10)
+  x = manip_bin_numerics( c( v, NA) )
+  expect_true( is.factor(x) )
+  expect_true( 'NA' %in% levels(x) )
+  
+  test_bin_labels = function( bin_label){
+    x = manip_bin_numerics( c( v, NA), bin_labels = bin_label )
+    expect_true( 'NA' %in% levels(x) )
+    y = manip_bin_numerics( v, bin_labels = bin_label )
+    expect_true( all( levels(y) %in% levels(x) ) )
+    expect_false( all( levels(x) %in% levels(y) ) )
+  }
+  
+  test_bin_labels('median')
+  test_bin_labels('mean')
+  test_bin_labels('min_max')
+  test_bin_labels('cuts')
+  
+  df = mtcars2 %>%
+    bind_rows( mtcars2['cyl'][1,] ) %>%
+    manip_bin_numerics() %>%
+    select( - cyl ) %>%
+    select_if( is.factor) %>%
+    summarise_all( function(x) list(levels(x)) ) %>%
+    summarise_all( function(x) 'NA' %in% unlist(x) )
+  
+  expect_true( all( as.matrix( df[1,] ) ) )
+  
+})
\ No newline at end of file
